# Flutes

[![Build Status](https://github.com/huzecong/flutes/workflows/Build/badge.svg)](https://github.com/huzecong/flutes/actions?query=workflow%3ABuild+branch%3Amaster)
[![CodeCov](https://codecov.io/gh/huzecong/flutes/branch/master/graph/badge.svg?token=ELHfYJ2Ydq)](https://codecov.io/gh/flutes/argtyped)
[![Documentation Status](https://readthedocs.org/projects/flutes/badge/?version=latest)](https://flutes.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/flutes.svg)](https://pypi.org/project/flutes/)
[![MIT License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/huzecong/flutes/blob/master/LICENSE)

> The utilities you need to charm your Python

[Flutes](https://github.com/huzecong/flutes) is a set of handy utilities for Python 3.6+. All tools are type checked and
covered by unit tests.

## Installation

Install stable release from PyPI:
```bash
pip install flutes
```

Or, install the latest commit from GitHub:
```bash
pip install git+https://github.com/huzecong/flutes.git
```

## Usage

Flutes provides a variety of utility functions. Take a look at the
[examples](https://github.com/huzecong/flutes/blob/master/examples) folder to see what you can do with it! 

Please refer to the [documentations](https://flutes.readthedocs.io/en/stable/) for more details.
